@@ -75,7 +75,7 @@ static int no_flush_read;
 /* read from a socket with IO timeout. return the number of
    bytes read. If no bytes can be read then exit, never return
    a number <= 0 */
-static int read_timeout(int fd, char *buf, int len)
+static int read_timeout(int fd, char *buf, size_t len)
 {
 	int n, ret=0;
 
@@ -137,7 +137,7 @@ static int read_timeout(int fd, char *buf, int len)
 
 /* continue trying to read len bytes - don't return until len
    has been read */
-static void read_loop(int fd, char *buf, int len)
+static void read_loop(int fd, char *buf, size_t len)
 {
 	while (len) {
 		int n = read_timeout(fd, buf, len);
@@ -150,7 +150,7 @@ static void read_loop(int fd, char *buf, int len)
 /* read from the file descriptor handling multiplexing - 
    return number of bytes read
    never return <= 0 */
-static int read_unbuffered(int fd, char *buf, int len)
+static int read_unbuffered(int fd, char *buf, size_t len)
 {
 	static int remaining;
 	char ibuf[4];
@@ -237,7 +237,7 @@ static void read_check(int f)
 
 /* do a buffered read from fd. don't return until all N bytes
    have been read. If all N can't be read then exit with an error */
-static void readfd(int fd,char *buffer,int N)
+static void readfd(int fd,char *buffer,size_t N)
 {
 	int  ret;
 	int total=0;  
@@ -303,12 +303,12 @@ int64 read_longint(int f)
 	return ret;
 }
 
-void read_buf(int f,char *buf,int len)
+void read_buf(int f,char *buf,size_t len)
 {
 	readfd(f,buf,len);
 }
 
-void read_sbuf(int f,char *buf,int len)
+void read_sbuf(int f,char *buf,size_t len)
 {
 	read_buf(f,buf,len);
 	buf[len] = 0;
@@ -326,7 +326,7 @@ unsigned char read_byte(int f)
 /* write len bytes to fd, possibly reading from buffer_f_in if set
    in order to unclog the pipe. don't return until all len
    bytes have been written */
-static void writefd_unbuffered(int fd,char *buf,int len)
+static void writefd_unbuffered(int fd,char *buf,size_t len)
 {
 	int total = 0;
 	fd_set w_fds, r_fds;
@@ -439,7 +439,7 @@ void io_end_buffering(int fd)
 	}
 }
 
-static void writefd(int fd,char *buf,int len)
+static void writefd(int fd,char *buf,size_t len)
 {
 	stats.total_written += len;
 
@@ -486,7 +486,7 @@ void write_longint(int f, int64 x)
 	writefd(f,b,8);
 }
 
-void write_buf(int f,char *buf,int len)
+void write_buf(int f,char *buf,size_t len)
 {
 	writefd(f,buf,len);
 }
@@ -503,7 +503,7 @@ void write_byte(int f,unsigned char c)
 	write_buf(f,(char *)&c,1);
 }
 
-int read_line(int f, char *buf, int maxlen)
+int read_line(int f, char *buf, size_t maxlen)
 {
 	eof_error = 0;
 
@@ -570,7 +570,7 @@ void io_start_multiplex_in(int fd)
 }
 
 /* write an message to the error stream */
-int io_multiplex_write(int f, char *buf, int len)
+int io_multiplex_write(int f, char *buf, size_t len)
 {
 	if (!io_multiplexing_out) return 0;
 
