@@ -87,8 +87,11 @@ void log_open(void)
 	int len;
 	FILE *f=NULL;
 	extern int am_daemon;
+	extern int quiet;
 	/* recursion can happen with certain fatal conditions */
 
+	if (quiet != 0 && fd == FINFO) return;
+
 	va_start(ap, format);
 	len = vslprintf(buf, sizeof(buf), format, ap);
 	va_end(ap);
@@ -189,6 +192,8 @@ static void log_formatted(int fd,
 	extern int am_daemon;
 	int64 b;
 
+	memset(buf,0,sizeof(buf));
+
 	strlcpy(buf, format, sizeof(buf));
 	
 	for (s=&buf[0]; 
@@ -250,7 +255,7 @@ static void log_formatted(int fd,
 
 		l = strlen(n);
 
-		if ((l-1) + ((int)(s - &buf[0])) > sizeof(buf)) {
+		if (l + ((int)(s - &buf[0])) > sizeof(buf)) {
 			rprintf(FERROR,"buffer overflow expanding %%%c - exiting\n",
 				p[0]);
 			exit_cleanup(RERR_MESSAGEIO);
@@ -289,9 +294,9 @@ void log_recv(struct file_struct *file, struct stats *initial_stats)
 	extern char *log_format;
 
 	if (lp_transfer_logging(module_id)) {
-		log_formatted(FLOG, lp_log_format(module_id), "send", file, initial_stats);
+		log_formatted(FLOG, lp_log_format(module_id), "recv", file, initial_stats);
 	} else if (log_format && !am_server) {
-		log_formatted(FINFO, log_format, "send", file, initial_stats);
+		log_formatted(FINFO, log_format, "recv", file, initial_stats);
 	}
 }
 
